# Parallel: 並列実行

この並列実行プラグインでは複数のアイテムを同時実行することができます。これは、たとえば、動的な刺激の表示と応答を同時に行う場合に便利です。

**注意:** 一部のシステムでは、スレッド(並列に実行されているプロセスがキーボードイベントを受け取ることができません。並列実行プラグインの最初の項目は、メインプロセスで実行されます。したがって、キーボードの押下に反応しない場合は、キーボード応答アイテムを最初のアイテムとして配置してみてください。
